import { DeclarationOption } from 'typedoc';
/**
 *
 * TypeDoc creates documentation according to exports derived from the given [`entryPointsStrategy`](https://typedoc.org/options/input/#entrypointstrategy) configuration.
 *
 * This option does not alter the way TypeDoc interprets the `entryPointsStrategy` but rather provides some flexibility as to how output files are generated.
 *
 * The following keys are available:
 *
 * @members
 *
 * Generates an individual file for each exported member. This is the standard behaviour of the HTML theme and the plugin default.
 *
 * @modules
 *
 * Generates a single file for every Module or Namespace where all members are hoisted to a single module file. This creates a flat navigation structure and reduces the amount of files generated.
 *
 * @category Output
 */
export declare const outputFileStrategy: Partial<DeclarationOption>;
/**
 * The entry page is the root page of the documentation, equivalent to `index.html` for web pages.
 *
 * `README.md` is recognised when browsing folders on repos and Wikis and is the plugin default. `index.md` might be more suitable for other use-cases.
 *
 * The content of this file will be resolved in the following order:
 *
 * 1. The value of the [`entryModule`](#entrymodule) option (if defined).
 * 2. The resolved Readme file (skipped if the TypeDoc [`readme`](https://typedoc.org/options/input/#readme) option is set to `none`).
 * 3. The documentation index page.
 *
 * @example "index.md"
 *
 * @category Output
 *
 */
export declare const entryFileName: Partial<DeclarationOption>;
/**
 * This option can be used when the root page of the documentation should be a specific module (typically a module named `index`).
 *
 * Please note a seperate modules index page will not be generated, therefore would work better if navigation is present.
 *
 * @example "index"
 *
 * @category Output
 */
export declare const entryModule: Partial<DeclarationOption>;
/**
 * By default when a readme file is resolved, a seperate readme page is created. This option prepends the readme contents into the index page so only a single root page is generated.
 *
 * This option has no effect when [`readme`](https://typedoc.org/options/input/#readme) is set to `"none"`.
 *
 * @category Output
 *
 */
export declare const mergeReadme: Partial<DeclarationOption>;
/**
 * @category UI
 */
export declare const hidePageHeader: Partial<DeclarationOption>;
/**
 * @category UI
 */
export declare const hidePageTitle: Partial<DeclarationOption>;
/**
 * @category UI
 */
export declare const hideBreadcrumbs: Partial<DeclarationOption>;
/**
 * @deprecated In-page TOC is now hidden as default.
 *
 * @category UI
 */
export declare const hideInPageTOC: Partial<DeclarationOption>;
/**
 * Provides a mechanism to change the main project index page title.
 *
 * @deprecated Please use `textContentMappings`.
 *
 * @category UI
 *
 */
export declare const indexPageTitle: Partial<DeclarationOption>;
/**
 * Provides a mechanism to configure the page title of members.
 *
 * @deprecated Please use `textContentMappings`.
 *
 * @category UI
 */
export declare const memberPageTitle: Partial<DeclarationOption>;
/**
 * By default members are grouped by kind (eg Classes, Functions etc).
 *
 * This creates a flat structure where all members are displayed at the same heading level.
 *
 * @category UI
 */
export declare const excludeGroups: Partial<DeclarationOption>;
/**
 * This option can be used to improve readability and aesthetics when defining signatures and declarations.
 *
 * Please note that when this option is set to `true` it is not possible to link to other references.
 *
 * As a work around the [`@link`](https://typedoc.org/tags/link/) tag can be be used to manually reference types.
 *
 * @category UI
 */
export declare const useCodeBlocks: Partial<DeclarationOption>;
/**
 * By default objects inside declarations are collapsed to preserve space and improve readability.
 *
 * This option should be set when a full object representation is preferred.
 *
 * @Default
 *
 * `Object`
 *
 * @Expanded
 *
 * \{ `x`: `string` }
 *
 * @category UI
 */
export declare const expandObjects: Partial<DeclarationOption>;
/**
 * This option either renders parameters for functions and class methods as a list or in tabular format.
 *
 * @category UI
 */
export declare const parametersFormat: Partial<DeclarationOption>;
/**
 *  This option either renders properties for classes and interfaces as a list or in tabular format.
 *
 * @category UI
 *
 */
export declare const propertiesFormat: Partial<DeclarationOption>;
/**
 * This option either renders members of enums as a list or in tabular format.
 *
 * @category UI
 */
export declare const enumMembersFormat: Partial<DeclarationOption>;
/**
 * This option either renders type declrations as a list or in tabular format.
 *
 * @category UI
 */
export declare const typeDeclarationFormat: Partial<DeclarationOption>;
/**
 * This option renders index items either as a simple list or in a table with a description column exposing the comment summary.
 *
 * @category UI
 */
export declare const indexFormat: Partial<DeclarationOption>;
/**
 * This option enables changing static text rendered to the documentation.
 * Useful if an alternative English phrase is preferred or to translate English text to another language.
 * This option does not attempt to address translating text within code comments.
 *
 * **Placeholders**
 *
 * Default values within curly braces `{}` indicates a placeholder of dynamic text.
 * The `{version}` placeholder requires the TypeDoc option [`includeVersion`](https://typedoc.org/options/input/#includeversion) to be true.
 *
 * **keys**
 *
 * Keys are categorised with the following namespace conventions:
 *
 * - `header.*` defines text in the page header (if displayed).
 * - `breadcrumbs.*` defines breadcrumbs in page header (if displayed).
 * - `title.*` defines text in main page titles.
 * - `label.*` other text in page content, including headings and table headers.
 * - `kind.*` defines text mappings to TypeDoc's `ReflectionKind` definitions.
 *
 * Only keys that require translation need to be added to the object.
 *
 * @category UI
 */
export declare const textContentMappings: Partial<DeclarationOption>;
/**
 * If undefined all urls will be relative.
 *
 * @example "http://abc.com"
 *
 * @category Utility
 */
export declare const publicPath: Partial<DeclarationOption>;
/**
 * By default references to symbol anchor links are lowercased.
 *
 * This option can be used for engines that require the preservation of anchor link casing.
 *
 * @category Utility
 */
export declare const preserveAnchorCasing: Partial<DeclarationOption>;
/**
 * This option should be used when parsers requiren a custom anchor prefix.
 *
 * @example "markdown-header"
 *
 * @category Utility
 */
export declare const anchorPrefix: Partial<DeclarationOption>;
/**
 * This option should be used if there are issues with anchoring to symbols within a page.
 *
 * - For markdown parsers that do not automatically assign header ids.
 * - When cross referencing symbols that are referenced in a table row.
 *
 * @category Utility
 */
export declare const namedAnchors: Partial<DeclarationOption>;
