"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.propertiesTable = void 0;
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function propertiesTable(context, props, isEventProps = false) {
    const modifiers = props.map((param) => context.helpers.getModifier(param));
    const hasModifiers = modifiers.some((value) => Boolean(value));
    const flags = props.map((param) => context.partials.reflectionFlags(param));
    const hasFlags = flags.some((value) => Boolean(value));
    const hasOverrides = props.some((prop) => Boolean(prop.overwrites));
    const hasInheritance = props.some((prop) => Boolean(prop.inheritedFrom));
    const hasComments = props.some((prop) => prop.comment?.blockTags?.length || prop?.comment?.summary?.length);
    const headers = [];
    headers.push(isEventProps
        ? context.getText('kind.event.singular')
        : context.getText('kind.property.singular'));
    if (hasModifiers) {
        headers.push(context.getText('label.modifier'));
    }
    if (hasFlags) {
        headers.push(context.getText('label.flags'));
    }
    headers.push(context.getText('label.type'));
    if (hasComments) {
        headers.push(context.getText('label.description'));
    }
    if (hasOverrides) {
        headers.push(context.getText('label.overrides'));
    }
    if (hasInheritance) {
        headers.push(context.getText('label.inheritedFrom'));
    }
    const rows = [];
    const declarations = context.helpers.flattenDeclarations(props);
    declarations.forEach((property, index) => {
        const propertyType = context.helpers.getDeclarationType(property);
        const row = [];
        const nameColumn = [];
        if (context.options.getValue('namedAnchors') && property.anchor) {
            nameColumn.push(`<a id="${property.anchor}" name="${property.anchor}"></a>`);
        }
        const propertyName = `${property.name}${property.flags.isOptional ? '?' : ''}`;
        if (property.isDeprecated && property.isDeprecated()) {
            nameColumn.push((0, markdown_1.strikeThrough)((0, markdown_1.backTicks)(propertyName)));
        }
        else {
            nameColumn.push((0, markdown_1.backTicks)(propertyName));
        }
        row.push(nameColumn.join(' '));
        if (hasModifiers) {
            row.push((0, markdown_1.backTicks)(modifiers[index] || 'public'));
        }
        if (hasFlags) {
            row.push(flags[index]);
        }
        if (propertyType) {
            const type = propertyType.declaration?.signatures?.length
                ? context.partials.functionType(propertyType?.declaration?.signatures, true)
                : context.partials.someType(propertyType);
            row.push((0, utils_1.stripLineBreaks)(type, false));
        }
        if (hasComments) {
            const hasComment = property.comment?.blockTags?.length ||
                property?.comment?.summary?.length;
            const comments = property?.comment;
            if (hasComment && comments) {
                row.push((0, utils_1.stripLineBreaks)((0, utils_1.formatTableDescriptionCol)(context.partials.comment(comments))));
            }
            else {
                row.push('-');
            }
        }
        if (hasOverrides) {
            row.push(context.partials.inheritance(property, -1) || '-');
        }
        if (hasInheritance) {
            row.push(context.partials.inheritance(property, -1) || '-');
        }
        rows.push(row);
    });
    return (0, markdown_1.table)(headers, rows);
}
exports.propertiesTable = propertiesTable;
