import { Options, Reflection } from 'typedoc';
import { MarkdownPageEvent, MarkdownTheme, TextContentMappings } from '..';
import { MarkdownRendererHooks } from '../plugin/types';
/**
 * The render context of the {@link MarkdownTheme}.
 * This follows the implementation of TypeDocs [DefaultThemeRenderContext](https://typedoc.org/api/classes/DefaultThemeRenderContext.html)
 */
export declare class MarkdownThemeRenderContext {
    private theme;
    readonly page: MarkdownPageEvent<Reflection> | null;
    readonly options: Options;
    /**
     * @param page The page this context is created for.
     * @param options The options used by TypeDoc. See TypeDoc's {@link typedoc!Options | Options} Class.
     */
    constructor(theme: MarkdownTheme, page: MarkdownPageEvent<Reflection> | null, options: Options);
    /**
     * A set of methods to return strings from specific TypeDoc models.
     *
     * These can be consumed by theme templates and partials using the syntax `context.models.method()`.
     */
    helpers: {
        flattenDeclarations: typeof import("./resources/helpers").flattenDeclarations;
        getDeclarationType: typeof import("./resources/helpers").getDeclarationType;
        getIndexTitle: typeof import("./resources/helpers").getIndexTitle;
        getKeyword: typeof import("./resources/helpers").getKeyword;
        getModifier: typeof import("./resources/helpers").getModifier;
        getParameterDefaultValue: typeof import("./resources/helpers").getParameterDefaultValue;
        isGroupKind: typeof import("./resources/helpers").isGroupKind;
    };
    /**
     * The theme's global templates context.
     */
    templates: {
        memberTemplate: (page: MarkdownPageEvent<import("typedoc").DeclarationReflection>) => string;
        projectTemplate: (page: MarkdownPageEvent<import("typedoc").ProjectReflection>) => string;
        readmeTemplate: (page: MarkdownPageEvent<import("typedoc").ProjectReflection>) => string;
        reflectionTemplate: (page: MarkdownPageEvent<import("typedoc").DeclarationReflection>) => string;
    };
    /**
     * The theme's global partials context.
     */
    partials: {
        breadcrumbs: (page: MarkdownPageEvent<import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection>) => string;
        commentParts: (parts: import("typedoc").CommentDisplayPart[]) => string;
        comment: (comment: import("typedoc").Comment, headingLevel?: number | undefined, showSummary?: boolean | undefined, showTags?: boolean | undefined) => string;
        header: (page: MarkdownPageEvent<import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection>) => string;
        pageIndex: (page: MarkdownPageEvent<import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection>, headingLevel: number) => string;
        reflectionIndex: (reflection: import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection, headingLevel: number) => string;
        linkTo: (label: string, url?: string | undefined) => string;
        parametersList: (parameters: import("typedoc").ParameterReflection[]) => string;
        typeParametersList: (typeParameters: import("typedoc").TypeParameterReflection[]) => string;
        accessorMember: (declaration: import("typedoc").DeclarationReflection, headingLevel: number) => string;
        constructorMember: (reflection: import("typedoc").DeclarationReflection, headingLevel: number) => string;
        declarationMemberIdentifier: (reflection: import("typedoc").DeclarationReflection) => string;
        declarationMember: (declaration: import("typedoc").DeclarationReflection, headingLevel: number, nested?: boolean | undefined) => string;
        memberHierarchy: (declarationHierarchy: import("typedoc").DeclarationHierarchy, headingLevel: number) => string;
        indexSignatureTitle: (signature: import("typedoc").SignatureReflection) => string;
        inheritance: (reflection: import("typedoc").DeclarationReflection | import("typedoc").SignatureReflection, headingLevel: number) => string;
        referenceMember: (props: import("typedoc").ReferenceReflection) => string;
        reflectionMember: (reflection: import("typedoc").DeclarationReflection, headingLevel: number) => string;
        signatureMemberIdentifier: (signature: import("typedoc").SignatureReflection, opts?: {
            accessor?: string | undefined;
            includeType?: boolean | undefined;
        } | undefined) => string;
        signatureParameters: (parameters: import("typedoc").ParameterReflection[], format?: boolean | undefined) => string;
        signatureMemberReturns: (signature: import("typedoc").SignatureReflection, headingLevel: number) => string;
        signatureMember: (signature: import("typedoc").SignatureReflection, headingLevel: number, nested?: boolean | undefined, accessor?: string | undefined) => string;
        sources: (reflection: import("typedoc").DeclarationReflection | import("typedoc").SignatureReflection, headingLevel: number) => string;
        memberTitle: (reflection: import("typedoc").DeclarationReflection) => string;
        member: (reflection: import("typedoc").DeclarationReflection, headingLevel: number, nested?: boolean | undefined) => string;
        typeDeclarationMember: (typeDeclaration: import("typedoc").DeclarationReflection, headingLevel: number) => string;
        members: (container: import("typedoc").ContainerReflection, headingLevel: number) => string;
        pageTitle: (page: MarkdownPageEvent<import("typedoc").DeclarationReflection | import("typedoc").ProjectReflection>) => string;
        reflectionFlags: (reflection: Reflection) => string;
        enumMembersTable: (props: import("typedoc").DeclarationReflection[]) => string;
        parametersTable: (parameters: import("typedoc").ParameterReflection[]) => string;
        propertiesTable: (props: import("typedoc").DeclarationReflection[], isEventProps?: boolean | undefined) => string;
        typeDeclarationTable: (props: import("typedoc").DeclarationReflection[]) => string;
        typeParametersTable: (typeParameters: import("typedoc").TypeParameterReflection[]) => string;
        typeArguments: (typeArguments: import("typedoc").SomeType[], foreCollpase?: boolean | undefined) => string;
        arrayType: (arrayType: import("typedoc").ArrayType) => string;
        conditionalType: (conditionalType: import("typedoc").ConditionalType) => string;
        declarationType: (declarationReflection: import("typedoc").DeclarationReflection) => string;
        functionType: (signatures: import("typedoc").SignatureReflection[], forceParameterType?: boolean | undefined) => string;
        indexAccessType: (model: import("typedoc").IndexedAccessType) => string;
        inferredType: (model: import("typedoc").InferredType) => string;
        intersectionType: (model: import("typedoc").IntersectionType) => string;
        intrinsicType: (model: import("typedoc").IntrinsicType) => string;
        literalType: (literalType: import("typedoc").LiteralType) => string;
        namedTupleType: (member: import("typedoc").NamedTupleMember) => string;
        queryType: (queryType: import("typedoc").QueryType) => string;
        referenceType: (referenceType: import("typedoc").ReferenceType, foreCollpase?: boolean | undefined) => string;
        reflectionType: (reflectionType: import("typedoc").ReflectionType, foreCollpase?: boolean | undefined) => string;
        someType: (someType: import("typedoc").SomeType, foreCollpase?: boolean | undefined) => string;
        tupleType: (tupleType: import("typedoc").TupleType) => string;
        typeOperatorType: (model: import("typedoc").TypeOperatorType) => string;
        unionType: (unionType: import("typedoc").UnionType) => string;
        unknownType: (model: import("typedoc").UnknownType) => string;
    };
    getText(key: keyof TextContentMappings): string;
    getTextFromKindString(kindString: string, isPlural?: boolean): string;
    parseUrl: (url: string) => string;
    /**
     * Hook into the TypeDoc rendering system.
     */
    hook: (name: keyof MarkdownRendererHooks) => string[];
}
