"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkdownTheme = void 0;
const typedoc_1 = require("typedoc");
const plugin_1 = require("../plugin");
const text_mappings_1 = require("../plugin/options/text-mappings");
const navigation_1 = require("./core/navigation");
const urls_1 = require("./core/urls");
const theme_render_context_1 = require("./theme-render-context");
/**
 * This is in-built MarkdownTheme which extends TypeDocs Theme class.
 * This follows the implementation of TypeDoc's {@link DefaultTheme}.
 *
 */
class MarkdownTheme extends typedoc_1.Theme {
    constructor(renderer) {
        super(renderer);
        this.readmeTemplate = (page) => {
            return this.getRenderContext(page).templates.readmeTemplate(page);
        };
        this.projectTemplate = (page) => {
            return this.getRenderContext(page).templates.projectTemplate(page);
        };
        this.reflectionTemplate = (page) => {
            return this.getRenderContext(page).templates.reflectionTemplate(page);
        };
        this.memberTemplate = (page) => {
            return this.getRenderContext(page).templates.memberTemplate(page);
        };
        this.textMappings = {
            ...text_mappings_1.TEXT_MAPPING_DEFAULTS,
            ...(this.application.options.getValue('textContentMappings') || {}),
        };
    }
    /**
     * Renders a template and page model to a string.
     */
    render(page, template) {
        try {
            return (template(page)
                .replace(/[\r\n]{3,}/g, '\n\n')
                .replace(/^\s+|\s+$/g, '') + '\n');
        }
        catch (e) {
            console.log(e);
            this.application.logger.error(`Error rendering page ${page.url}.`);
            throw new Error(e);
        }
    }
    getRenderContext(page) {
        return new theme_render_context_1.MarkdownThemeRenderContext(this, page, this.application.options);
    }
    getUrls(project) {
        return (0, urls_1.getUrls)(this, project);
    }
    getNavigation(project) {
        return (0, navigation_1.getNavigation)(this, project);
    }
    getText(key) {
        return this.textMappings[key];
    }
    getTextFromKindString(kindString, isPlural = false) {
        const key = isPlural
            ? text_mappings_1.PLURAL_KIND_KEY_MAP[kindString]
            : text_mappings_1.SINGULAR_KIND_KEY_MAP[kindString];
        return this.textMappings[key] || kindString;
    }
    getTemplateMapping(kind, outputFileStrategyOverride) {
        const outputFileStrategy = outputFileStrategyOverride ||
            this.application.options.getValue('outputFileStrategy');
        const directoryName = (reflectionKind) => {
            const pluralString = typedoc_1.ReflectionKind.pluralString(reflectionKind);
            return pluralString.replace(/[\s_-]+/g, '-').toLowerCase();
        };
        const memberMapping = (template, kind) => {
            return {
                template,
                directory: directoryName(kind),
                kind: kind,
            };
        };
        const mappings = {
            [typedoc_1.ReflectionKind.Module]: {
                template: this.reflectionTemplate,
                directory: null,
                kind: typedoc_1.ReflectionKind.Module,
            },
            [typedoc_1.ReflectionKind.Namespace]: {
                template: this.reflectionTemplate,
                directory: directoryName(typedoc_1.ReflectionKind.Namespace),
                kind: typedoc_1.ReflectionKind.Namespace,
            },
        };
        if (outputFileStrategy === plugin_1.OutputFileStrategy.Members) {
            mappings[typedoc_1.ReflectionKind.Class] = memberMapping(this.reflectionTemplate, typedoc_1.ReflectionKind.Class);
            mappings[typedoc_1.ReflectionKind.Interface] = memberMapping(this.reflectionTemplate, typedoc_1.ReflectionKind.Interface);
            mappings[typedoc_1.ReflectionKind.Enum] = memberMapping(this.reflectionTemplate, typedoc_1.ReflectionKind.Enum);
            mappings[typedoc_1.ReflectionKind.Function] = memberMapping(this.memberTemplate, typedoc_1.ReflectionKind.Function);
            mappings[typedoc_1.ReflectionKind.TypeAlias] = memberMapping(this.memberTemplate, typedoc_1.ReflectionKind.TypeAlias);
            mappings[typedoc_1.ReflectionKind.Variable] = memberMapping(this.memberTemplate, typedoc_1.ReflectionKind.Variable);
        }
        return mappings[kind];
    }
}
exports.MarkdownTheme = MarkdownTheme;
